summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/sms/smsservice.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/sms/smsservice.h')
-rw-r--r--kopete/protocols/sms/smsservice.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/kopete/protocols/sms/smsservice.h b/kopete/protocols/sms/smsservice.h
index c1d46563..d448570b 100644
--- a/kopete/protocols/sms/smsservice.h
+++ b/kopete/protocols/sms/smsservice.h
@@ -28,9 +28,10 @@ namespace Kopete { class Account; }
class TQGridLayout;
class TQWidget;
-class SMSService : public QObject
+class SMSService : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
SMSService(Kopete::Account* account = 0);
virtual ~SMSService();
@@ -44,11 +45,11 @@ public:
virtual void setAccount(Kopete::Account* account);
/**
* Called when the settings widget has a place to be. @param parent is the
* settings widget's parent and @param layout is the 2xn grid layout it may
* use.
*/
- virtual void setWidgetContainer(TQWidget* parent, TQGridLayout* layout) = 0;
+ virtual void setWidgetContainer(TQWidget* tqparent, TQGridLayout* tqlayout) = 0;
virtual void send(const Kopete::Message& msg) = 0;
virtual int maxSize() = 0;
@@ -44,11 +45,11 @@ public:
virtual void setAccount(Kopete::Account* account);
/**
- * Called when the settings widget has a place to be. @param parent is the
- * settings widget's parent and @param layout is the 2xn grid layout it may
+ * Called when the settings widget has a place to be. @param tqparent is the
+ * settings widget's tqparent and @param tqlayout is the 2xn grid tqlayout it may
* use.
*/